ImageMode
=========

.. currentmodule:: toasty.image

.. autoclass:: ImageMode
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageMode.F16x3
      ~ImageMode.F32
      ~ImageMode.F64
      ~ImageMode.RGB
      ~ImageMode.RGBA
      ~ImageMode.U8

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageMode.from_array_info
      ~ImageMode.make_maskable_buffer
      ~ImageMode.try_as_pil

   .. rubric:: Attributes Documentation

   .. autoattribute:: F16x3
   .. autoattribute:: F32
   .. autoattribute:: F64
   .. autoattribute:: RGB
   .. autoattribute:: RGBA
   .. autoattribute:: U8

   .. rubric:: Methods Documentation

   .. automethod:: from_array_info
   .. automethod:: make_maskable_buffer
   .. automethod:: try_as_pil
